#![allow(incomplete_features)]
#![feature(specialization)]

pub mod streams;
pub mod serialize;
pub mod primitives;
pub mod varint;
pub mod error;



//pub struct Added<T, const N: u32>(PhantomData<*const T>);
//pub struct Removed<T, const N: u32>(PhantomData<*const T>);